﻿package
{
    import flash.display.Bitmap;
    import flash.display.Sprite;
    import flash.text.TextField;
    import flash.text.TextFormat;       
	import flash.display.MovieClip;
    import flash.events.GeolocationEvent;
	import flash.events.StatusEvent; 
    import flash.sensors.Geolocation;
    import flash.display.StageAlign;
    import flash.display.StageScaleMode;    
    
    /**
     * Document class for Compass application. 
     * Sample application 
     *  
     * @author Rich Wagner
     * 
     */      
    public class Compass extends MovieClip
    {
        // Geolocation     
        private var geo:Geolocation;        
        
        // External images 
        [Embed(source="north.jpg")]
        private var NorthImage:Class;
        
        [Embed(source="south.jpg")]
        private var SouthImage:Class;

        [Embed(source="east.jpg")]
        private var EastImage:Class;

        [Embed(source="west.jpg")]
        private var WestImage:Class;
    
        // Bitmaps for each direction     
        private var north:Bitmap; 
        private var south:Bitmap; 
        private var east:Bitmap; 
        private var west:Bitmap; 
        
        /**
         * Constructor  
         * 
         */           
        public function Compass()
        {

            stage.scaleMode = StageScaleMode.NO_SCALE;
            stage.align = StageAlign.TOP_LEFT;            
            
            if (Geolocation.isSupported)
            {
                geo = new Geolocation();
                geo.setRequestedUpdateInterval(200);
                geo.addEventListener(GeolocationEvent.UPDATE, geolocationUpdateHandler);
				geo.addEventListener(StatusEvent.STATUS, geolocationStatusHandler);

                // Create bitmaps     
                north = new NorthImage();
                north.smoothing = true;
                north.visible = false; 
                addChild(north); 
                                
                south = new SouthImage();
                south.smoothing = true;
                south.visible = false; 
                addChild(south); 
                
                east = new EastImage();
                east.smoothing = true;
                east.visible = false; 
                addChild(east); 
                
                west = new WestImage();
                west.smoothing = true;            
                west.visible = false; 
                addChild(west); 
            
            }
            else
            {
                noSupportNotify(); 
            }            
            
            
        }
        
        /**
         * Toggles visibility of bitmaps to display current direction
         *  
         * @param bitmap 
         * 
         */
        private function updateUI(bitmap:Bitmap):void
        {
            north.visible = (north == bitmap); 
            south.visible = (south == bitmap); 
            east.visible = (east == bitmap); 
            west.visible = (west == bitmap); 
        }
        
        
        /**
         * Called each time the geolocation services updates app  
         * 
         * @param event
         * 
         */
        private function geolocationUpdateHandler(event:GeolocationEvent):void
        {
            var h:Number = event.heading; 
            
            if ( (h > 316) || (h < 45)) 
                updateUI(north)
            else if ( (h > 46) && (h < 135)) 
                updateUI(east)
            else if ( (h > 136) && (h < 225)) 
                updateUI(south)
            else if ( (h > 226) && (h < 315)) 
                updateUI(west)
                
        }        

        
        /**
         * Notifies the user that no service is available due to lack of
         * geo-awareness of device.   
         * 
         */
        private function noSupportNotify():void
        {
            var tfInfo:TextField = new TextField();
            var format:TextFormat = new TextFormat("Helvetica", 22);
            format.color = 0x000000; 
            tfInfo.defaultTextFormat = format;
            tfInfo.border = false;
            tfInfo.wordWrap = true;
            tfInfo.multiline = true;
            tfInfo.x = 10;
            tfInfo.y = 10;
            tfInfo.height = stage.stageHeight - 20;
            tfInfo.width = stage.stageWidth - 20;
            tfInfo.text =  "No geolocation services available.";
           	addChild(tfInfo);  
        }


        /**
         * Called each time the status changes
         * 
         * @param event
         * 
         */
        private function geolocationStatusHandler(event:StatusEvent):void
        {
            // If user is not allowing updates, then display 
            if (geo.muted)  
                noSupportNoify();
        }


    }
}