﻿package
{
    import flash.display.SimpleButton;
    import flash.display.Sprite;
    import flash.display.StageAlign;
    import flash.display.StageScaleMode;
    import flash.events.*;
    import flash.events.GeolocationEvent;
    import flash.net.*;
    import flash.net.URLVariables;
    import flash.sensors.Geolocation;
    import flash.text.TextField;
    import flash.text.TextFormat;

    /**
     * Document class for FindMeAPizza application. 
     * iPhone Development with Flash sample app 
     *  
     * @author Rich Wagner
     * 
     */        
    public class FindMeAPizza extends Sprite
    {
            
        // Geolocation     
        private var geo:Geolocation;
        
        // TextField 
        private var tfInfo:TextField; 
        
        // Coordinates 
        private var longitude:Number; 
        private var latitude:Number; 
        
        /**
         * Constructor  
         * 
         */            
        public function FindMeAPizza()
        {
            
            stage.scaleMode = StageScaleMode.NO_SCALE;
            stage.align = StageAlign.TOP_LEFT;
            
            tfInfo = new TextField();
            var format:TextFormat = new TextFormat("Helvetica", 20);
            format.color = 0xffffff; 
            tfInfo.defaultTextFormat = format;
            tfInfo.border = true;
            tfInfo.wordWrap = true;
            tfInfo.multiline = true;
            tfInfo.x = 10;
            tfInfo.y = 10;
            tfInfo.height = stage.stageHeight - 80;
            tfInfo.width = stage.stageWidth - 20;            
            addChild(tfInfo);

            // Geolocation setup             
            if (Geolocation.isSupported)
            {
                geo = new Geolocation();
                geo.setRequestedUpdateInterval(5000);
                geo.addEventListener(GeolocationEvent.UPDATE, geolocationUpdateHandler);
                
                // Enable button if location provided 
                btnFind.addEventListener(MouseEvent.CLICK, buttonClickHandler);                
                tfInfo.text =  "Click the Find button to find your nearest pizza shop.";
            }
            else
            {
                tfInfo.text =  "Can't find where you are. No pizza for you.";
            }        
        }            
        
        /**
         * Triggers a pizza lookup  
         * 
         * @param event
         * 
         */        
        private function buttonClickHandler(event:MouseEvent):void
        {
            fetch(); 
        }            
         
        
        /**
         * Main routine for fetching pizza data. Sets up URL params.  
         * 
         */        
        public function fetch():void 
        {

            var url:String = "http://local.yahooapis.com/LocalSearchService/V3/localSearch";
            var variables:URLVariables = new URLVariables();
            variables.appid="x77v8JvV34GL7auv9T_lFPBhWqJIEwk..3DpsJ3Ds0LODlQA1qdshBHMreEbYEI3y_iGUuMGBvVJrQ--"; 
            variables.query="pizza";
            variables.latitude = latitude; 
            variables.longitude = longitude; 
            variables.radius = "300"; 
			variables.results = "1"; 
            sendData(url, variables);
        }
        
        /**
         * Helper function that makes the URL request to Yahoo  
         * 
         * @param url
         * @param vars
         * 
         */        
        public function sendData(url:String, vars:URLVariables):void 
        {
            var request:URLRequest = new URLRequest(url);
            var loader:URLLoader = new URLLoader();
            request.data = vars;
            request.method = URLRequestMethod.POST;
            loader.addEventListener(Event.COMPLETE, completeHandler);
            loader.addEventListener(IOErrorEvent.IO_ERROR, iOErrorHandler);
            loader.load(request);
        }
        
        /**
         * Handler for server response  
         *  
         * @param event
         * 
         */        
        private function completeHandler(event:Event):void 
        {
            // Get response and convert to XML 
            var response:String = event.target.data as String;
            try
            {
                var xml:XML = cleanResponse(response);
            }
            catch(error:TypeError)
            {
                writeLn("The response data was not in valid XML format");
            }
            
            // Get all <Result> children. Only one in this case, but 
            // you could expand to handle multiple results. 
            var item:XML;        
            var results:XMLList = xml.descendants("Result"); 
            
            // If no matches, then let user know bad news 
            if (results.length() == 0)
            {
                writeLn("You are at least 300 miles from the nearest pizza shop. No pizza for you. "); 
            }    
            // Otherwise, write out closest match 
            else
            {                
                for each(item in results) 
                {       
                    var s:String = "Your closest pizza shop is: \n" + 
                                    item.Title + "\n" + 
                                    item.Address + "\n" + 
                                    item.City + ", " +  
                                    item.State + "\n" + 
                                    item.Phone; 
                    writeLn(s);
                }
            }
            
        }

        /**
         * Handler for IO errors with server 
         *  
         * @param event
         * 
         */        
        private function iOErrorHandler(event:IOErrorEvent):void 
        {
            writeLn("Error loading URL.");
        }


        /**
         * Called each time the geolocation services updates app  
         * 
         * @param event
         * 
         */
        private function geolocationUpdateHandler(event:GeolocationEvent):void
        {
            latitude = event.latitude;
            longitude = event.longitude; 
        }
        
        /**
         * Helper utility method for writing text to the UI. 
         *  
         * @param s - text to write 
         * 
         */
        private function writeLn(s:String):void
        {
            tfInfo.text = s; 
        }            
        
        

        
        /**
         * Strips out unneeded namespace and schema definitions 
         *  
         * @param response - raw XML feed 
         * 
         * @returns XML instance  
         * 
         */
        private function cleanResponse(response:String):XML
        {
            const NP1:String =  'xmlns="urn:yahoo:lcl"'; 
            const NP2:String =  'xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"'; 
            const NP3:String =  'xsi:schemaLocation="urn:yahoo:lcl http://local.yahooapis.com/LocalSearchService/V3/LocalSearchResponse.xsd"'; 
            
            response = response.replace(NP1, "");
            response = response.replace(NP2, "");
            response = response.replace(NP3, "");
            
            return new XML(response); 
            
        }
        
        
    }
}